//
//  MSTFirstRunInstaller.h
//  
//
//  Created by Dirk Musfeldt on 09.06.06.
//  Copyright 2006 Meilenstein Software GmbH. All rights reserved.
//

#import <Cocoa/Cocoa.h>

/*
@"FirstRunVersion"; // version number to be compared with CFBundleKey
@"FirstRunDenied";    // NSArray with item dicts the user denied to install
@"FirstRunDelayed";  // NSArray with item dicts to be asked for later


 
// Keys for the item dicts in FirstRun.plist
// most of them are also used within MSTFirstRunDeniedItemsKey and MSTFirstRunDelayedItemsKey
 
@"ItemSource"; // name/path of item bundle
@"ItemDestination"; // name/path of item destination
@"InstallContents"; // bool value whether to install content items instead of single parent
@"InfoDictionary"; // name/path to dictionary with version information
@"AskUser";   // bool value wether to ask the user for a permission
@"UserExplanation"; // text to be displayed if the user is to be asked
@"RestartApplications";   // Array with bundle identifiers of applications to be restarted
@"DisplayName"; // name to be displayed to user
@"PostInstallScriptPath"; // name/path of script to run after installing item
*/


extern NSString * const MSTFirstRunInstallerDidFinishNotification;    // finished successfully
extern NSString * const MSTFirstRunInstallerDidFailNotification;      // finished with errors
extern NSString * const MSTFirstRunInstallerWasDelayedNotification;   // finished successfully but there were items delayed



@class SNDisclosableView, SFAuthorization;

@interface MSTFirstRunInstaller : NSObject
{
    IBOutlet NSWindow * askWindow;
    
    IBOutlet NSTextField *  headingField;
    IBOutlet NSTextField *  warningField;

    IBOutlet NSTextField *  explanationField;
    IBOutlet SNDisclosableView * disclosableView;
    IBOutlet NSButton *     disclosureButton;
    
    NSEnumerator * itemEnumerator;
    NSDictionary * currentItem;
    NSMutableArray * restartApplications;
    
    SFAuthorization * authorization;
    
    BOOL anItemFailed;
    
    BOOL ignorePreviousInstallations;
}

/*
 We have a singleton.
 */
+ (MSTFirstRunInstaller*)sharedInstaller;

/*
 Utility call
 */
+ (void)installIgnoringPreviousInstallations:(BOOL)ignoreFlag;

+ (void) deinstall;

/*
 This will reset all stored information about previous installations
 */
- (void)resetInstallation;

/*
 This is the main function.
 */
- (void)install;

/*
 Tests if the item with the given name should be installed
 */
- (BOOL)isItemInstalled:(NSString*)itemBundleName;

/*
 Tests wether the installer currently has user interaction, 
 i.e. wether a window is open.
*/
- (BOOL)isUserInteraction;

/*
 Tests wether the installer is currently running,
 i.e. wether the install loop is running or a window is open.
*/
- (BOOL)isActive;

/*
 Get and set the authorization. This may be used to prevent additional authorization requests.
 If you set the authorization make sure kAuthorizationRightExecute is permitted.
 */
- (SFAuthorization*)authorization;
- (void)setAuthorization:(SFAuthorization*)anAuthorization;


- (IBAction)commitInstall:(id)sender;

- (IBAction)delayInstall:(id)sender;

- (IBAction)denyInstall:(id)sender;

@end
