//
//  MSTPreferencesController.h
//  MSTPrefsFramework
//
//  Created by Christian Weykopf on 06.06.06.
//  Copyright 2006 Meilenstein Software GmbH. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@class MSTPreferencePane;

@interface MSTPreferencesController : NSObject
{
    NSWindow                *prefsWindow;
    NSMutableDictionary     *preferencePanes;
    NSMutableArray          *panesOrder;
    
    NSToolbar               *prefsToolbar;
    NSMutableDictionary     *prefsToolbarItems;
    
    NSToolbarDisplayMode    toolbarDisplayMode;
#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_2
    NSToolbarSizeMode       toolbarSizeMode;
#endif

    BOOL                    usesTexturedWindow;
    BOOL                    alwaysShowsToolbar;
    BOOL                    alwaysOpensCentered;
}

// we don't force use of +sharedPreferences to be compatible with existing code
+ (id)sharedPreferences;

// Convenience constructors
+ (id) preferences;
+ (id) preferencesWithPane: (MSTPreferencePane *)aPane;

    // Designated initializer
- (id) initWithPane: (MSTPreferencePane *)aPane;
- (void) addPane: (MSTPreferencePane *) aPane;

- (void) showPreferencesWindow;
- (void) createPreferencesWindowAndDisplay: (BOOL)shouldDisplay;
- (void) createPreferencesWindow;
- (void) destroyPreferencesWindow;
- (BOOL) loadPrefsPaneNamed: (NSString *)name display: (BOOL)disp;
- (BOOL) loadPreferencePaneNamed: (NSString *)name;
- (void) activatePane: (MSTPreferencePane *)pane;

float ToolbarHeightForWindow (NSWindow *window);
- (void) createPrefsToolbar;
- (void) prefsToolbarItemClicked: (NSToolbarItem *)item;

    // Accessors
- (NSWindow *) preferencesWindow;

- (NSArray *) loadedPanes;
- (NSArray *) panesOrder;
- (void) setPanesOrder: (NSArray *)newPanesOrder;
- (BOOL) usesTexturedWindow;
- (void) setUsesTexturedWindow: (BOOL)newUsesTexturedWindow;
- (BOOL) alwaysShowsToolbar;
- (void) setAlwaysShowsToolbar: (BOOL)newAlwaysShowsToolbar;
- (BOOL) alwaysOpensCentered;
- (void) setAlwaysOpensCentered: (BOOL)newAlwaysOpensCentered;
- (NSToolbarDisplayMode) toolbarDisplayMode;
- (void) setToolbarDisplayMode: (NSToolbarDisplayMode)displayMode;
#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_2
- (NSToolbarSizeMode) toolbarSizeMode;
- (void) setToolbarSizeMode: (NSToolbarSizeMode)sizeMode;
#endif

@end
