//
//  UCPServerConnectionProtocol.h
//  UCPFramework
//
//  Created by Christian Weykopf on 20.10.09.
//  Copyright 2009 STARFACE GmbH. All rights reserved.
//

enum
{
    stateNotConnected = 0,
    stateXMPPConnected = 1,
    stateClosed = 2,
    stateLoginSent = 3,
    stateEstablished = 4,
    stateLogoutSent = 5,
    stateAuthenticationError = 6
};
typedef UInt32 UCPServerConnectionState;

enum
{
    connectionGenericError = 1,
    connectionNetworkError
};
typedef UInt32 UCPServerConnectionError;

@interface NSObject (UCPServerConnectionRequest)

@property (assign) NSUInteger connectionState;

- (BOOL) loginOnHost: (NSString *)xmppHost 
                port: (NSUInteger)xmppPort 
              secure: (BOOL)secure 
       autoReconnect: (BOOL)autoReconnect 
            username: (NSString *)userName 
            password: (NSString *)password
            delegate: (id)delegate;
- (BOOL) logoutWithDelegate: (id) delegate;
- (BOOL) probeWithDelegate: (id)delegate;
- (BOOL) setProvidedServices: (NSArray *)providedServices delegate: (id)delegate;

@end

/*!
    @category   NSObject(UCPServerConnectionResponse)
    @brief      Informal protocol for the delegate.
 */
@interface NSObject (UCPServerConnectionResponse)

/*!
    @brief              Method to implement by the delegeate.
    @param connection   The UCPConnection sending the Message,
    @param newState     The new serverState.
 */
- (void) ucpServerConnection: (id)connection connectionStateChanged: (UCPServerConnectionState)newState;

/*!
    @brief              Method to implement by the delegeate.
    @param connection   The UCPConnection sending the Message,
    @param newState     The error.
 */
- (void) ucpServerConnection: (id)connection errorReceived: (UCPServerConnectionError)error;

@end

/*!
    @category   NSObject(UCPClientConnection)
    @brief      Informal protocol for the delegate.
 */
@interface NSObject (UCPClientConnection)

/*!
    @brief  Method to implement by the delegeate.
    @param  flag If YES the server sent reset call.
 */
- (void) connectionReset: (BOOL)YesNo;

@end
