//
//  UcpClient.h
//  UCPFramework
//
//  Created by Christian Weykopf on 21.09.09.
//  Copyright 2009 STARFACE GmbH. All rights reserved.
//

#import <Foundation/Foundation.h>

@class XMPPConnection;

/*!
    @brief    The UCP client.
    @details  The UCPClient class is mostly a forwarder to the separate client classes.
*/
@interface UCPClient : NSObject
{
    NSMutableDictionary *_clientStore;
    id _delegate;
    XMPPConnection *_xmppConnection;
}

@property (retain) NSMutableDictionary *clientStore;
@property (assign) id delegate;
@property (retain) XMPPConnection *xmppConnection;

/*!
    @brief   Designated initializer.
    @details Initializes the class and sets the delegate.
    @param   delegate The delegate for the receiver.
    @return  An initialized UCPClient object.
*/
- (id) initWithDelegate: (id)delegate;

/*!
    @brief   Adds a RPC-Client
    @details Adds a client for a specific UCP-service.
    @param   clientClass The client must conform to the SFClientProtocol.
*/
- (void) addClientClass: (Class)clientClass;


/*!
    @brief Array with the services of all clients.
    @return Array with the service names of all clents.
 */
- (NSArray *) providedServices;

@end
